function [density,omega] = calcAngleDistribution(odf,varargin)
% compute the angle distribution of an ODF or an MDF 
%
% Input
%  odf - @ODF
%  omega - list of angles
%
% Flags
%  even       - calculate even portion only
%
% Output
%  x   - values of the axis distribution
%
% See also

if nargin > 1 && isa(varargin{1},'ODF')
  odf = calcMDF(odf,varargin{1});
  varargin(1) = [];
end

if ~check_option(varargin,'fast')

  % get resolution
  res = get_option(varargin,'resolution',0.5*degree);
  
  % initialize evaluation grid
  S3G = quaternion;
  iS3G = 0;
  cs1 = odf.CS;
  cs2 = odf.SS;
  csU = union(cs1,cs2);
  csD = disjoint(cs1,cs2);
  
  % the angle distribution of the uniformODF
  if check_option(varargin,'omega')
    omega = get_option(varargin,'omega',[]);
    density = zeros(size(omega));
    d = angleDistribution(cs1,omega); % TODO this should probably be csU
    density(1:numel(d)) = d;
  else
    [density,omega] = angleDistribution(cs1); % TODO this should probably be csU
  end
  
  sR = csD.fundamentalSector;

  % for all angles
  for k=1:numel(omega)  
    
    S2G = equispacedS2Grid('points',max(1,round(4/3*sin(omega(k)/2).^2/res^2)),...
      sR,'RESTRICT2MINMAX'); % create a grid  TODO

    %S2G = S2Grid('random','points',max(1,numel(csD)*round(4/3*sin(omega(k)/2).^2/res^2)),...
    %  'minTheta',minTheta,'MAXTHETA',maxTheta,'MAXRHO',maxRho,'MINRHO',minRho,'RESTRICT2MINMAX'); % create a grid
    
    % create orientations
    o = axis2quat(S2G(:),omega(k));
    
    % and select those
    rotAngle = abs(dot_outer(o,odf.CS));
    maxAngle = max(rotAngle,[],2); 
    o = o(rotAngle(:,1)>maxAngle-0.0001);
    
    % store these orientations
    S3G = [S3G;o]; %#ok<AGROW>
    iS3G(k+1) = length(S3G); %#ok<AGROW>
    
  end
  
  % evaluate the ODF at the grid
  f = eval(odf,S3G); %#ok<EVLC>
  
  % integrate
  for k = 1:numel(omega)    
    if iS3G(k)<iS3G(k+1)
      density(k) = density(k) * mean(f(iS3G(k)+1:iS3G(k+1)));
    end
  end
  
else
      

  % get resolution
  points = get_option(varargin,'points',100000);
  
  % get resolution
  res = get_option(varargin,'resolution',2.5*degree);
  
  % simluate EBSD data
  ebsd = calcEBSD(odf,points,'resolution',res);

  % compute angles
  angles = ebsd.orientations.angle;

  maxangle = max(angles);


  % perform kernel density estimation

  [bandwidth,density,omega] = kde(angles,2^8,0,maxangle); %#ok<ASGLU>

  density = density ./ mean(density) * pi ./ maxangle;
  
end

% where to evaluate
%omega = linspace(0,maxangle,100);

% 
%sigma = 20;
%psi = @(a,b) exp(-(a-b).^2*sigma.^2);

%
%x = sum(bsxfun(psi,angles,omega));
%x = x./sum(x)*numel(x);
